"""
**AveyTense Extensions**

Availability: >= 0.3.26b3 \\
© 2024-Present Aveyzan // License: MIT \\
https://aveyzan.xyz/aveytense#aveytense.extensions

Similarly as `typing_extensions`, this module provides backports for Python types,
functions, classes and ABCs (especially generic).

About AVT types visit https://aveyzan.xyz/aveytense/glossary#avt_prefixed_types

This module occurred in many names:

- `aveytense.tcs` to 0.3.26rc2
- `aveytense.types_collection` during 0.3.26rc3 - 0.3.51
- `aveytense.types` during 0.3.52 - 0.3.56

Constants have been moved to separate submodule `aveytense.constants`.
"""

from __future__ import annotations

import collections.abc as _collections_abc
import collections as _collections
import hashlib as _hashlib
import sys as _sys
import typing as _typing

from ._collection._extensions import *
from ._collection._version import VERSION
from . import util as _util

if False: # 0.3.68
    NULL = type(None) # 0.3.26b3 (0.3.34 - type[None])
    null = NULL # 0.3.41

_T = TypeVar("_T")

if False: # < 0.3.27rc1
    @deprecated("Deprecated since 0.3.27a3, use class 'aveytense.types_collection.ClassVar' instead.")
    def classvar(v: _T, /):
        """
        Availability: >= 0.3.26b3 (experimental) \\
        @deprecated 0.3.27a3

        Transform variable in a class to a class variable.

        This will be valid only whether this function is \\
        invoked inside a class.
        Use it as:
        ```py \\
        class Example:
            test = classvar(96000) # has value 96000
        ```
        """
        class _t:
            _v: ClassVar[_T] = v
        return _t._v

    @deprecated("Deprecated since 0.3.26c3, use class 'aveytense.FinalVar' instead.")
    def finalvar(v: _T, /):
        """
        Availability: >= 0.3.26b3 \\
        @deprecated 0.3.26c3 (use `aveytense.FinalVar` class-like instead)

        Use it as:
        ```py \\
        reassign_me = finalvar(96000) # has value 96000
        reassign_me += 3 # error
        ```
        """
        return _util.FinalVar(v)
    

# EnchantedBookQuantity = _lit[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36] ### >= 0.3.26b3; < 0.3.52

if False: # < 0.3.41
    
    
    FileMode = Literal[
        'r+', '+r', 'rt+', 'r+t', '+rt', 'tr+', 't+r', '+tr', 'w+', '+w', 'wt+', 'w+t', '+wt', 'tw+', 't+w', '+tw', 'a+', '+a', 'at+', 'a+t', '+at', 'ta+', 't+a', '+ta', 'x+', '+x', 'xt+',
        'x+t', '+xt', 'tx+', 't+x', '+tx', 'w', 'wt', 'tw', 'a', 'at', 'ta', 'x', 'xt', 'tx', 'r', 'rt', 'tr', 'U', 'rU', 'Ur', 'rtU', 'rUt', 'Urt', 'trU', 'tUr', 'Utr', 'rb+', 'r+b', '+rb',
        'br+', 'b+r', '+br', 'wb+', 'w+b', '+wb', 'bw+', 'b+w', '+bw', 'ab+', 'a+b', '+ab', 'ba+', 'b+a', '+ba', 'xb+', 'x+b', '+xb', 'bx+', 'b+x', '+bx', 'rb', 'br', 'rbU', 'rUb', 'Urb',
        'brU', 'bUr', 'Ubr', 'wb', 'bw', 'ab', 'ba', 'xb', 'bx'
    ] # 0.3.26b3
    FileOpener = AVT_Callable[[str, int], int] # 0.3.26b3
    TicTacToeBoard = AVT_List[AVT_List[str]] # 0.3.26b3

    AnySequenceForPick = Union[AVT_Sequence[_T], AVT_MutableSequence[_T], AVT_Uniqual[_T], AVT_MutableUniqual[_T]] # 0.3.26c3

    SequencePickType = Union[
        AVT_List[_T],
        AVT_Tuple[_T, ...],
        AVT_Set[_T],
        AVT_FrozenSet[_T],
        ListConvertible[_T]
    ] # 0.3.26c3

    SequencePickNGT = _uni[
        list,
        tuple,
        set,
        frozenset,
        Sequence,
        ListConvertible
    ] # 0.3.26c3

if False: # < 0.3.52
    
    VarLenHash = type(_hashlib.shake_256()) # it can appear as local hashlib._VarLenHash class in Python versions before 3.13 (0.3.41)
    "Availability: >= 0.3.26rc3"

    BlakeHash = _hashlib.blake2b
    "Availability: >= 0.3.26rc3"

    List = list # 0.3.26b3
    "Availability: >= 0.3.26b3"

    if _sys.version_info >= (3, 9):
        Tuple = tuple # 0.3.26b3
        "Availability: >= 0.3.26b3"
        
    else:
        Tuple = _typing.Tuple # 0.3.26b3
        "Availability: >= 0.3.26b3"

    Deque = _collections.deque # 0.3.26b3
    "Availability: >= 0.3.26b3"

    Dict = dict # 0.3.26b3
    "Availability: >= 0.3.26b3"

    Bytes = bytes # 0.3.26b3
    "Availability: >= 0.3.26b3"

    ByteArray = bytearray # 0.3.26b3
    "Availability: >= 0.3.26b3"

    Filter = filter # 0.3.26b3
    "Availability: >= 0.3.26b3"

    Type = type # 0.3.26b3
    "Availability: >= 0.3.26b3"

    Zip = zip # 0.3.26b3
    "Availability: >= 0.3.26b3"

    Slice = slice # 0.3.26c1
    "Availability: >= 0.3.26rc1"

    Object = object
    "Availability: >= 0.3.26rc3"

if False: # < 0.3.41 (if no removal version was provided, then all of these were removed in 0.3.41)
    
    class _FinalVar(NamedTuple, Generic[_T]):
        x: _T
    
    ModernReplace = _uni[list[_T], tuple[_T, ...], _T]
    # since 0.3.25, expected string; renamed from SupportsModernReplace (0.3.26b3)
    PickSequence = _uni[list[_T], tuple[_T, ...], set[_T], frozenset[_T], _collections.deque[_T], _collections_abc.Sequence[_T], _collections_abc.MutableSequence[_T]]
    # since 0.3.25, added support for Sequence and MutableSequence, renamed from SupportsPick (0.3.26b3)
    SanitizeMode = _lit[0, 1, 2, 3, 4, 5]
    # since 0.3.25, renamed from SupportsSanitizeMode (0.3.26b3)
    SupportsAbroadDivisor = _uni[int, float]
    # since 0.3.25; removed in 0.3.26b3, use FloatOrInteger instead
    ShuffleType = _uni[str, list[_T], _collections_abc.MutableSequence[_T]]
    # since 0.3.26rc1
    TypeOrFinalVarType = _uni[_T, _FinalVar[_T]]
    # since 0.3.26rc1
    
    __author__ = "Aveyzan <aveyzan@gmail.com>"
    "Availability: >= 0.3.26rc3"
    __license__ = "MIT"
    "Availability: >= 0.3.26rc3"
    __version__ = VERSION
    "Availability: >= 0.3.26rc3"


if False: # < 0.3.46

    ProbabilityType = _uni[_T, list[_opt[_T]], tuple[_T, _opt[_T]], dict[_T, _opt[_T]], _collections.deque[_opt[_T]], set[_opt[_T]], frozenset[_opt[_T]]]
    # since 0.3.25, expected integer; renamed from SupportsProbabilityValuesAndFrequencies (0.3.26b3)
    

TenseVersionType = AVT_Tuple[_T, _T, _T]
# since 0.3.25, renamed from SupportsTenseVersion (0.3.26b3)

FloatOrInteger = Union[int, float] # since 0.3.25
_IntegerConvertible = Union[str, Buffer, IntegerConvertible, Indexable, Truncable] # since 0.3.26rc1
_FloatConvertible = Union[str, Buffer, FloatConvertible, Indexable] # since 0.3.26rc1
_ComplexConvertible = Union[complex, FloatConvertible, Indexable] # since 0.3.26rc1

if False: # < 0.3.48
    
    @deprecated("Deprecated since 0.3.41, will be removed on 0.3.48. Migrate to 'int' builtin instead")
    class Integer:
        """
        Availability: >= 0.3.26b3
        
        Equivalent to `int`. Once instantiated, it returns \\
        integer of type `int`. (0.3.26c1)
        """
        def __new__(cls, x: _IntegerConvertible = ..., /):
            """
            Availability: >= 0.3.26b3
            
            Equivalent to `int`. Once instantiated, it returns \\
            integer of type `int`. (0.3.26c1)
            """
            return int(x)
        
        def __instancecheck__(self, obj: object, /) -> TypeIs[int]:
            return isinstance(obj, int)

    @deprecated("Deprecated since 0.3.41, will be removed on 0.3.48. Migrate to 'float' builtin instead")
    class Float:
        """
        Availability: >= 0.3.26b3
        
        Equivalent to `float`. Once instantiated, it returns \\
        number of type `float`. (0.3.26c1)
        """
        def __new__(cls, x: _FloatConvertible = ..., /):
            """
            Availability: >= 0.3.26b3
            
            Equivalent to `float`. Once instantiated, it returns \\
            number of type `float`. (0.3.26c1)
            """
            return float(x)
        
        def __instancecheck__(self, obj: object, /) -> TypeIs[float]:
            return isinstance(obj, float)

    @deprecated("Deprecated since 0.3.41, will be removed on 0.3.48. Migrate to 'complex' builtin instead")
    class Complex:
        """
        Availability: >= 0.3.26b3
        
        Equivalent to `complex`. Once instantiated, it returns \\
        number of type `complex`. (0.3.26c1)
        """
        def __new__(cls, r: _uni[ComplexConvertible, _ComplexConvertible] = ..., i: _ComplexConvertible = ..., /):
            """
            Availability: >= 0.3.26b3
            
            Equivalent to `complex`. Once instantiated, it returns \\
            number of type `complex`. (0.3.26c1)
            """
            return complex(r, i)
        
        def __instancecheck__(self, obj: object, /) -> TypeIs[complex]:
            return isinstance(obj, complex)

    @deprecated("Deprecated since 0.3.41, will be removed on 0.3.48. Migrate to 'str' builtin instead")
    class String:
        """
        Availability: >= 0.3.26b3
        
        Equivalent to `str`. Once instantiated, it returns \\
        string of type `str`. (0.3.26c1)
        """
        def __new__(cls, x: object = ..., /):
            """
            Availability: >= 0.3.26b3
            
            Equivalent to `str`. Once instantiated, it returns \\
            string of type `str`. (0.3.26c1)
            """
            return str(x)
        
        def __instancecheck__(self, obj: object, /) -> TypeIs[str]:
            return isinstance(obj, str)

    @deprecated("Deprecated since 0.3.41, will be removed on 0.3.48. Migrate to 'bool' builtin instead")
    class Boolean:
        """
        Availability: >= 0.3.26b3
        
        Equivalent to `bool`. Once instantiated, it returns \\
        boolean of type `bool`. (0.3.26c1)
        """
        def __new__(cls, x: object = ..., /):
            """
            Availability: >= 0.3.26b3
            
            Equivalent to `bool`. Once instantiated, it returns \\
            boolean of type `bool`. (0.3.26c1)
            """
            return bool(x)
        
        def __instancecheck__(self, obj: object, /) -> TypeIs[bool]:
            return obj is True or obj is False

################ TypeScript References ################
# Remove these on 0.3.54.

if False: # < 0.3.54
    false = False
    "Availability: >= 0.3.26rc3"
    true = True
    "Availability: >= 0.3.26rc3"
    never = Never
    "Availability: >= 0.3.26rc3"
    number = Union[int, float] # on JavaScript there is no 'complex' number type
    "Availability: >= 0.3.26rc3"
    void = type(None)
    "Availability: >= 0.3.26rc3"

__all__ = sorted([n for n in globals() if n[:1] != "_"])
"Availability: >= 0.3.26rc1? Whole gamut of declarations written in `aveytense.extensions` module"

__all_deprecated__ = sorted([n for n in globals() if hasattr(globals()[n], "__deprecated__")])
"""
Availability: >= 0.3.41

Returns all deprecated declarations within this module.
"""

__constants__ = [n for n in __all__ if n.isupper()]
"Availability: >= 0.3.26rc3. All constants in `aveytense.extensions` module"

__non_constants__ = [n for n in __all__ if not n.isupper()]
"Availability: >= 0.3.26rc3. All non-constants (functions, classes, type aliases) in `aveytense.extensions` module"

__abc__ = [n for n in __all__ if is_protocol(globals()[n]) or (isinstance(globals()[n], ABC) and n in _collections_abc.__dict__)]
"Availability: >= 0.3.26rc3. ABCs (Abstract Base Classes) in `aveytense.extensions` module"

if __name__ == "__main__":
    error = RuntimeError("Import-only module")
    raise error



# py -m build
# twine upload dist/* --config-file ./config.pypirc

from setuptools import setup
from aveytense import __version__

long_description = \
"""
# AveyTense

**AveyTense** is a library written in Python, which provides especially extensions to inbuilt Python solutions.

## Features

Some feature examples:

* [`aveytense.Tense.append()`](https://aveyzan.xyz/aveytense#aveytense.Tense.append) - A pure, extended version of `list.append()` that adds an arbitrary amount of items, starting
with items in the given iterable object.

```py

from aveytense import Tense

Tense.append([651, 78, 888, 906], 75, 12, 6, 678)
# [651, 78, 888, 906, 75, 12, 6, 678]

Tense.append({762: 783, 9003: 96}, (960, 120), (762, 786))
# {762: 786, 960: 120, 762: 786}

```

* [`aveytense.Tense.extend()`](https://aveyzan.xyz/aveytense#aveytense.Tense.extend) - A pure, extended version of `list.extend()` that adds an arbitrary amount of items included in
every iterable objects, starting with items in the first given iterable object.

```py

from aveytense import Tense

Tense.extend([651, 78, 888, 906], (75, 12), {6, 678})
# [651, 78, 888, 906, 75, 12, 6, 678]

Tense.extend({762: 783, 9003: 96}, {960: 120}, {762: 786})
# {762: 786, 960: 120, 762: 786}

```

* [`aveytense.Tense.reverse()`](https://aveyzan.xyz/aveytense#aveytense.Tense.reverse) - A pure, extended version of `list.reverse()` that reverses
given iterable object.

```py

from aveytense import Tense

Tense.reverse("Hi, Python! Hi, AveyTense!")
# "!esneTyevA ,iH !nohtyP ,iH"

Tense.reverse([762, 876, 906, 903, 123])
# [123, 903, 906, 876, 762]

```

* [`aveytense.Tense.shuffle()`](https://aveyzan.xyz/aveytense#aveytense.Tense.shuffle) - A pure, extended version of `random.shuffle()` that shuffles given iterable object.

```py

from aveytense import Tense

Tense.shuffle("Hi, Python! Hi, AveyTense!")
# " ,sPh y!ti,neeTo!HvHeyA ni"

Tense.shuffle([762, 876, 906, 903, 123])
# [762, 906, 903, 123, 876]

```

More features are included in [this page](https://aveyzan.xyz/aveytense). For code changes see [this Google document](https://docs.google.com/document/d/1GC_KAOXML65jNfBZA8GhVViqPnrMoFtbLv_jHvUhBlg/edit?usp=sharing).

## Getting started

Before installing AveyTense, ensure you meet following Python version condition included in the table below:

| AveyTense Version | Python Version |
| :---------------- | :------------- |
| ≥ 0.3.46          | ≥ 3.8          |
| < 0.3.46          | ≥ 3.9          |

Then run the following command:

```
pip install aveytense
```

The command will also install [`typing_extensions`](https://pypi.org/project/typing_extensions). Minimal version of `typing_extensions` project for
AveyTense to run correctly is 4.10.0 (version of adding `TypeIs` to the project).

After installation process, you can import module `aveytense`, which imports AveyTense components into your project.

If you think you are out of date, consider checking out [releases section](https://pypi.org/project/aveytense/#history) and running following command:

```py
pip install --upgrade aveytense
```

If you have AveyTense 0.3.54 or higher, you can also use the following command to upgrade AveyTense:

```py
aveytense-upgrade
```

To view version of AveyTense, you can use [`importlib.metadata.version()`](https://docs.python.org/3/library/importlib.metadata.html#importlib.metadata.version), `aveytense.__version__`,
[`aveytense.Tense.version`](https://aveyzan.xyz/aveytense#aveytense.Tense.version), [`aveytense.Tense.versionInfo`](https://aveyzan.xyz/aveytense#aveytense.Tense.versionInfo)
or since AveyTense 0.3.54 the command below:

```py
aveytense-version
```

This project can be used anywhere, including for educational and enternainment/game purposes. 

## Support

If you found anomalies in code, need more information about the project or/and want to suggest changes,
consider sending mail to [my email](mailto:aveyzan@gmail.com) or creating an issue in [the GitHub repository](https://github.com/Aveyzan/AveyTense/issues).
Bug fixes will be issued in future versions of AveyTense. The project isn't intended to be a malware.

AveyTense project maintained on PyPi since 7th August 2024.

© 2024-Present Aveyzan // License: MIT
"""

setup(
    name = 'aveytense',
    version = __version__, # check this before uploading!!
    description = "Library written in Python, includes several extensions for inbuilt Python solutions",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    author_email = "aveyzan@gmail.com",
    author = 'Aveyzan',
    license = "MIT",
    packages = [
        "aveytense",
        "aveytense._collection"
    ],
    keywords = [
        "annotations",
        "backport",
        "extensions",
        "math",
        "types",
        "typing",
        "utility"
    ],
    classifiers = [
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent", 
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Programming Language :: Python :: 3.14",
        "Programming Language :: Python :: 3.15",
        "Topic :: Software Development"
    ],
    package_data = {
        "aveytense": ["py.typed"],
    },
    include_package_data = True,
    install_requires = [
        ### this limit will change if backporting further, up to Python 3.6
        # "typing_extensions >= 4.10.0; python_version >= '3.8'",
        # "typing_extensions >= 4.7.0; python_version == '3.7'",
        # "typing_extensions >= 4.1.0; python_version == '3.6'"
        "typing_extensions >= 4.10.0"
    ],
    python_requires = ">=3.8", # >=3.6 if support factually provided
    project_urls = {
        "Documentation": "https://aveyzan.xyz/aveytense/",
        "Repository": "https://github.com/Aveyzan/aveytense",
        "Changes": "https://docs.google.com/document/d/1GC_KAOXML65jNfBZA8GhVViqPnrMoFtbLv_jHvUhBlg/edit?usp=sharing",
        "Issues": "https://github.com/Aveyzan/aveytense/issues/",
        "Donate": "https://ko-fi.com/aveyzan"
    },
    entry_points = {
        "console_scripts": [
            "aveytense-update = aveytense._collection._console:upgrade",
            "aveytense-version = aveytense._collection._console:version"
        ],
    }
)


"""
**AveyTense Functions**

Availability: >= 0.3.68 \\
© 2024-Present Aveyzan // License: MIT \\
https://aveyzan.xyz/aveytense#aveytense.functions

Ports class methods of `Tense` and `Math` as functions. Unlike all other modules in `aveytense` module, this one must be imported within the `import` statement.
"""

from aveytense import Tense, Math

### 0.3.68

# Math
abs = Math.abs
acos = Math.acos
acosec = Math.acosec
acosech = Math.acosech
acosh = Math.acosh
acot = Math.acot
acoth = Math.acoth
acovercos = Math.acovercos
acoversin = Math.acoversin
addPercentage = Math.addPercentage
aexcosec = Math.aexcosec
aexsec = Math.aexsec
ahacovercos = Math.ahacovercos
ahacoversin = Math.ahacoversin
ahavercos = Math.ahavercos
ahaversin = Math.ahaversin
asec = Math.asec
asech = Math.asech
asin = Math.asin
asinh = Math.asinh
atan = Math.atan
atanh = Math.atanh
avercos = Math.avercos
aversin = Math.aversin
cbrt = Math.cbrt
cos = Math.cos
cosec = Math.cosec
cosech = Math.cosech
cosh = Math.cosh
covercos = Math.covercos
coversin = Math.coversin
cube = Math.cube
cubeCentered = Math.cubeCentered
decagonal = Math.decagonal
decagonalCentered = Math.decagonalCentered
diagonals = Math.diagonals
dodecagonal = Math.dodecagonal
dodecagonalCentered = Math.dodecagonalCentered
dodecahedral = Math.dodecahedral
dodecahedralCenetered = Math.dodecahedralCentered
excosec = Math.excosec
exsec = Math.exsec
fact = Math.fact
factFalling = Math.factFalling
factRising = Math.factRising
fib = Math.fib
fma = Math.fma
gcd = Math.gcd
hacovercos = Math.hacovercos
hacoversin = Math.hacoversin
havercos = Math.havercos
haversin = Math.haversin
hendecagonal = Math.hendecagonal
hendecagonalCentered = Math.hendecagonalCentered
heptagonal = Math.heptagonal
heptagonalCentered = Math.hendecagonalCentered
hexagonal = Math.hexagonal
hexagonalCentered = Math.hexagonalCentered
icosahedral = Math.icosahedral
icosahedralCentered = Math.icosahedralCentered
isComposite = Math.isComposite
isConstant = Math.isConstant
isDecimal = Math.isDecimal
isDecreasing = Math.isDecreasing
isFraction = Math.isFraction
isInRange = Math.isInRange
isIncreasing = Math.isIncreasing
isMonotonous = Math.isMonotonous
isNonDecreasing = Math.isNonDecreasing
isNonIncreasing = Math.isNonIncreasing
isNegative = Math.isNegative
isNumber = Math.isNumber
isPositive = Math.isPositive
isPrime = Math.isPrime
lcm = Math.lcm
ln = Math.ln
log = Math.log
log2 = Math.log2
log3 = Math.log3
log5 = Math.log5
log7 = Math.log7
log10 = Math.log10
lwdp = Math.lwdp
maxDigit = Math.maxDigit
mean = Math.mean
minDigit = Math.minDigit
nonagonal = Math.nonagonal
nonagonalCentered = Math.nonagonalCentered
octagonal = Math.octagonal
octagonalCentered = Math.octagonalCentered
octahedral = Math.octahedral
octahedralCentered = Math.octahedralCentered
pentagonal = Math.pentagonal
pentagonalCentered = Math.pentagonalCentered
pentatope = Math.pentatope
perm = Math.perm
polygonal = Math.polygonal
polygonalCentered = Math.polygonalCentered
pow = Math.pow
pronic = Math.pronic
pyramidal = Math.pyramidal
sec = Math.sec
sech = Math.sech
sin = Math.sin
sinh = Math.sinh
sqrt = Math.sqrt
square = Math.square
squareCentered = Math.squareCentered
star = Math.star
stdev = Math.stdev
stellaOctangula = Math.stellaOctangula
tan = Math.tan
tanh = Math.tanh
tetrahedral = Math.tetrahedral
tetrahedralCentered = Math.tetrahedralCentered
toDegrees = Math.toDegrees
toDigits = Math.toDigits
toGradians = Math.toGradians
toRadians = Math.toRadians
toScientific = Math.toScientific
triangular = Math.triangular
triangularCentered = Math.triangularCentered
tridecagonal = Math.tridecagonal
tridecagonalCentered = Math.tridecagonalCentered
trunc = Math.trunc
vercos = Math.vercos
versin = Math.versin

# Tense
abroadBinary = Tense.abroadBinary
abroadConvect = Tense.abroadConvect
abroadEach = Tense.abroadEach
abroadExclude = Tense.abroadExclude
abroadFloaty = Tense.abroadFloaty
abroadHex = Tense.abroadHex
abroadInside = Tense.abroadInside
abroadNegative = Tense.abroadNegative
abroadNegativeFlip = Tense.abroadNegativeFlip
abroadOctal = Tense.abroadOctal
abroadPack = Tense.abroadPack
abroadPositive = Tense.abroadPositive
abroadPositiveFlip = Tense.abroadPositiveFlip
abroadPrecede = Tense.abroadPrecede
abroadSplit = Tense.abroadSplit
abroadSufcede = Tense.abroadSufcede
all = Tense.all
any = Tense.any
append = Tense.append
architecture = Tense.architecture
asyncGenerator = Tense.asyncGenerator
cast = Tense.cast
clear = Tense.clear
copy = Tense.copy
deepcopy = Tense.deepcopy
difference = Tense.difference
disassemble = Tense.disassemble
endsWith = Tense.endsWith
equal = Tense.equal
exclude = Tense.exclude
expect = Tense.expect
explode = Tense.explode
extend = Tense.extend
extract = Tense.extract
first = Tense.first
flatten = Tense.flatten
generator = Tense.generator
getAllItemsTypes = Tense.getAllItemsTypes
getAttr = Tense.getAttr
getFlags = Tense.getFlags
getGeneric = Tense.getGeneric
group = Tense.group
hasAttr = Tense.hasAttr
improvedBogoSort = Tense.improvedBogoSort
inequal = Tense.inequal
isAbroad = Tense.isAbroad
isArray = Tense.isArray
isAsyncGenerator = Tense.isAsyncGenerator
isAwaitable = Tense.isAwaitable
isBinary = Tense.isBinary
isBool = Tense.isBool
isBoolean = Tense.isBoolean
isByteArray = Tense.isByteArray
isBytes = Tense.isBytes
isClass = Tense.isClass
isComplex = Tense.isComplex
isCoroutine = Tense.isCoroutine
isDeprecated = Tense.isDeprecated
isDeque = Tense.isDeque
isDict = Tense.isDict
isEllipsis = Tense.isEllipsis
isFinalClass = Tense.isFinalClass
isFinalProperty = Tense.isFinalProperty
isFinalVar = Tense.isFinalVar
isFloat = Tense.isFloat
isFrozenSet = Tense.isFrozenSet
isFunction = Tense.isFunction
isGenerator = Tense.isGenerator
isGeneric = Tense.isGeneric
isHexadecimal = Tense.isHexadecimal
isIn = Tense.isIn
isInt = Tense.isInt
isInteger = Tense.isInteger
isIterable = Tense.isIterable
isIterator = Tense.isIterator
isLambda = Tense.isLambda
isList = Tense.isList
isMemoryView = Tense.isMemoryView
isNone = Tense.isNone
isNumeric = Tense.isNumeric
isOctal = Tense.isOctal
isProperty = Tense.isProperty
isSet = Tense.isSet
isSlice = Tense.isSlice
isSpecialForm = Tense.isSpecialForm
isStr = Tense.isStr
isString = Tense.isString
isTuple = Tense.isTuple
isTuple2 = Tense.isTuple2
isType = Tense.isType
isUnbound = Tense.isUnbound # experimental
isUnion = Tense.isUnion
last = Tense.last
license = Tense.license
occurrences = Tense.occurrences
pick = Tense.pick
print = Tense.print
probability = Tense.probability
probability2 = Tense.probability2
probability3 = Tense.probability3
random = Tense.random
randomString = Tense.randomString
removePrefix = Tense.removePrefix
removeSuffix = Tense.removeSuffix
reverse = Tense.reverse
shuffle = Tense.shuffle
sleep = Tense.sleep
splitGeneric = Tense.splitGeneric
startsWith = Tense.startsWith
test = Tense.test
timeit = Tense.timeit
toList = Tense.toList
tryOrPass = Tense.tryOrPass
tryOrReturn = Tense.tryOrReturn
until = Tense.until
union = Tense.union

del Math, Tense

__all__ = [k for k in globals() if not k.startswith("_")]